@@ -1,6 +1,6 @@
 package Text::CSV_XS;
 
-# Copyright (c) 2007-2011 H.Merijn Brand.  All rights reserved.
+# Copyright (c) 2007-2012 H.Merijn Brand.  All rights reserved.
 # Copyright (c) 1998-2001 Jochen Wiedmann. All rights reserved.
 # Portions Copyright (c) 1997 Alan Citterman. All rights reserved.
 #
@@ -27,7 +27,7 @@ use DynaLoader ();
 use Carp;
 
 use vars   qw( $VERSION @ISA );
-$VERSION = "0.85";
+$VERSION = "0.86";
 @ISA     = qw( DynaLoader );
 bootstrap Text::CSV_XS $VERSION;
 
@@ -58,6 +58,7 @@ my %def_attr = (
     always_quote	=> 0,
     quote_space		=> 1,
     quote_null		=> 1,
+    quote_binary	=> 1,
     binary		=> 0,
     keep_meta_info	=> 0,
     allow_loose_quotes	=> 0,
@@ -107,7 +108,8 @@ sub new
 
     for (keys %{$attr}) {
 	if (m/^[a-z]/ && exists $def_attr{$_}) {
-	    $] >= 5.008002 && m/_char$/ and utf8::decode ($attr->{$_});
+	    defined $attr->{$_} && $] >= 5.008002 && m/_char$/ and
+		utf8::decode ($attr->{$_});
 	    next;
 	    }
 #	croak?
@@ -149,6 +151,7 @@ my %_cache_id = ( # Only expose what is accessed from within PM
     auto_diag		=> 24,
     quote_space		=> 25,
     quote_null		=> 31,
+    quote_binary	=> 32,
     _is_bound		=> 26,	# 26 .. 29
     );
 
@@ -243,6 +246,13 @@ sub quote_null
     $self->{quote_null};
     } # quote_null
 
+sub quote_binary
+{
+    my $self = shift;
+    @_ and $self->_set_attr_X ("quote_binary", shift);
+    $self->{quote_binary};
+    } # quote_binary
+
 sub binary
 {
     my $self = shift;
@@ -992,6 +1002,13 @@ you to treat the NULL byte as a simple binary character in binary mode (the
 C<< { binary => 1 } >> is set). The default is true.  You can prevent NULL
 escapes by setting this attribute to 0.
 
+=item quote_binary
+X<quote_binary>
+
+By default,  all "unsafe" bytes inside a string cause the combined field to
+be quoted. By setting this attribute to 0, you can disable that trigger for
+bytes >= 0x7f.
+
 =item keep_meta_info
 X<keep_meta_info>
 
@@ -1064,6 +1081,7 @@ is equivalent to
      always_quote        => 0,
      quote_space         => 1,
      quote_null	         => 1,
+     quote_binary        => 1,
      binary              => 0,
      keep_meta_info      => 0,
      allow_loose_quotes  => 0,
@@ -1923,7 +1941,7 @@ ChangeLog releases 0.25 and on.
 
 =head1 COPYRIGHT AND LICENSE
 
- Copyright (C) 2007-2011 H.Merijn Brand for PROCURA B.V. All rights reserved.
+ Copyright (C) 2007-2012 H.Merijn Brand for PROCURA B.V. All rights reserved.
  Copyright (C) 1998-2001 Jochen Wiedmann. All rights reserved.
  Portions Copyright (C) 1997 Alan Citterman. All rights reserved.
 
